#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MAXNUMMAG_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MAXNUMMAG_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/maxnummag.hpp>

#endif
